@@ -24,7 +24,7 @@ import aws_cdk.aws_lambda as lambda_
 fn.add_layers(NodeProxyAgentLayer(self, "NodeProxyAgentLayer"))
 ```
 
-[`proxy-agent`](https://www.npmjs.com/package/proxy-agent) will be installed under `/opt/nodejs/node_modules`.
+[`proxy-agent`](https://www.npmjs.com/package/proxy-agent) will be installed under `/nodejs/node_modules`.
 '''
 import abc
 import builtins
